@@ -518,6 +518,8 @@ edge.betweenness.community <- function(graph, weights=E(graph)$weight,
   res$algorithm <- "edge betweenness"
   res$membership <- res$membership + 1
   res$merges <- res$merges + 1
+  res$removed.edges <- res$removed.edges + 1
+  res$bridges <- res$bridges + 1
   class(res) <- "communities"
   res
 }
@@ -569,8 +571,8 @@ community.to.membership <- function(graph, merges, steps, membership=TRUE,
   merges <- structure(as.numeric(merges), dim=dim(merges))
   
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  .Call("R_igraph_community_to_membership", graph, merges, as.numeric(steps),
-        as.logical(membership), as.logical(csize),
+  .Call("R_igraph_community_to_membership", graph, merges-1,
+        as.numeric(steps), as.logical(membership), as.logical(csize),
         PACKAGE="igraph")
 }
 
