@@ -139,7 +139,8 @@ E <- function(graph, P=NULL, path=NULL, directed=TRUE) {
                    PACKAGE="igraph")
       tmp[as.numeric(x)]
     }
-    i <- eval(i, envir=c(unclass(graph)[[9]][[3]], nei=nei, innei=innei,
+    i <- eval(i, envir=c(.Call("R_igraph_mybracket2", graph, 9L, 3L,
+                   PACKAGE="igraph"), nei=nei, innei=innei,
                    outnei=outnei, adj=adj, inc=inc, from=from, to=to),
               enclos=parent.frame())
     if (is.numeric(i) || is.integer(i)) {
@@ -201,10 +202,13 @@ E <- function(graph, P=NULL, path=NULL, directed=TRUE) {
                    PACKAGE="igraph")
       tmp[ as.numeric(x) ]
     }
-    i <- eval(i, envir=c(unclass(graph)[[9]][[4]],
+    i <- eval(i, envir=c(.Call("R_igraph_mybracket2", graph, 9L, 4L,
+                   PACKAGE="igraph"),
                    inc=inc, adj=adj, from=from, to=to,
-                   .igraph.from=list(unclass(graph)[[3]][ as.numeric(x) ]),
-                   .igraph.to=list(unclass(graph)[[4]][as.numeric(x)]),
+                   .igraph.from=list(.Call("R_igraph_mybracket",
+                     graph, 3L, PACKAGE="igraph")[ as.numeric(x) ]),
+                   .igraph.to=list(.Call("R_igraph_mybracket",
+                     graph, 4L, PACKAGE="igraph")[as.numeric(x)]),
                    .igraph.graph=list(graph),
                    `%--%`=`%--%`, `%->%`=`%->%`, `%<-%`=`%<-%`),
               enclos=parent.frame())
@@ -364,12 +368,18 @@ as.igraph.vs <- function(graph, v, na.ok=FALSE) {
       stop("Invalid vertex names")
     }
     v
-  } else if (is.logical(v)) {
-    as.vector(V(graph))[v]
-  } else if (is.numeric(v) && any(v<=0)){
-    as.vector(V(graph))[v]
   } else {
-    as.numeric(v)
+    if (is.logical(v)) {
+      res <- as.vector(V(graph))[v]
+    } else if (is.numeric(v) && any(v<=0)){
+      res <- as.vector(V(graph))[v]
+    } else {
+      res <- as.numeric(v)
+    }
+    if (!na.ok && any(is.na(res))) {
+      stop("Invalid vertex name(s)")
+    }
+    res
   }
 }
 
