@@ -1,8 +1,8 @@
 /* -*- mode: C -*-  */
 /* 
    IGraph library.
-   Copyright (C) 2006  Gabor Csardi <csardi@rmki.kfki.hu>
-   MTA RMKI, Konkoly-Thege Miklos st. 29-33, Budapest 1121, Hungary
+   Copyright (C) 2006-2012  Gabor Csardi <csardi.gabor@gmail.com>
+   334 Harvard street, Cambridge, MA 02139 USA
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,9 +26,11 @@
 int main() {
   
   igraph_t g;
-  igraph_integer_t result;
+  igraph_real_t result;
   
-  igraph_barabasi_game(&g, 30, 30, 0, 0, IGRAPH_DIRECTED);
+  igraph_barabasi_game(&g, 30, /*power=*/ 1, 30, 0, 0, /*A=*/ 1, 
+		       IGRAPH_DIRECTED, IGRAPH_BARABASI_BAG,
+		       /*start_from=*/ 0);
   igraph_average_path_length(&g, &result, IGRAPH_UNDIRECTED, 1);
   
 /*   printf("Length of the average shortest paths: %f\n", (float) result); */
