@@ -1,8 +1,8 @@
 /* -*- mode: C -*-  */
 /* 
    IGraph library.
-   Copyright (C) 2007  Gabor Csardi <csardi@rmki.kfki.hu>
-   MTA RMKI, Konkoly-Thege Miklos st. 29-33, Budapest 1121, Hungary
+   Copyright (C) 2007-2012  Gabor Csardi <csardi.gabor@gmail.com>
+   334 Harvard st, Cambridge MA, 02139 USA
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -28,9 +28,9 @@ int main() {
   igraph_t g;
   igraph_integer_t girth;
   igraph_vector_t v;
-  igraph_integer_t chord[] = { 0, 50 };
+  igraph_real_t chord[] = { 0, 50 };
   igraph_ring(&g, 100, IGRAPH_UNDIRECTED, 0, 1);
-  igraph_vector_view(&v, chord, sizeof(chord)/sizeof(igraph_integer_t));
+  igraph_vector_view(&v, chord, sizeof(chord)/sizeof(igraph_real_t));
   igraph_add_edges(&g, &v, 0);
   igraph_girth(&g, &girth, 0);
   if (girth != 51) {
