@@ -1,8 +1,8 @@
 /* -*- mode: C -*-  */
 /* 
    IGraph library.
-   Copyright (C) 2006  Gabor Csardi <csardi@rmki.kfki.hu>
-   MTA RMKI, Konkoly-Thege Miklos st. 29-33, Budapest 1121, Hungary
+   Copyright (C) 2006-2012  Gabor Csardi <csardi.gabor@gmail.com>
+   334 Harvard st, Cambridge MA, 02139 USA
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ int main() {
   f=fopen("igraph_layout_reingold_tilford.in", "r");
   igraph_read_graph_edgelist(&g, f, 0, 1);
   igraph_matrix_init(&coords, 0, 0);
-  igraph_layout_reingold_tilford(&g, &coords, 0); 
+  igraph_layout_reingold_tilford(&g, &coords, IGRAPH_IN, 0, 0); 
   
   /*n=igraph_vcount(&g);
   for (i=0; i<n; i++) {
