@@ -1,8 +1,8 @@
 /* -*- mode: C -*-  */
 /* 
    IGraph library.
-   Copyright (C) 2006  Gabor Csardi <csardi@rmki.kfki.hu>
-   MTA RMKI, Konkoly-Thege Miklos st. 29-33, Budapest 1121, Hungary
+   Copyright (C) 2006-2012  Gabor Csardi <csardi.gabor@gmail.com>
+   334 Harvard st, Cambridge MA, 02139 USA
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ void print_vector(igraph_vector_t *v, FILE *f) {
 int main() {
 
   igraph_t g;
-  igraph_vector_t v, res;
+  igraph_vector_t v, res, reset, weights;
   igraph_arpack_options_t arpack_options;
   igraph_real_t value;
   int ret;
@@ -93,6 +93,11 @@ int main() {
   igraph_pagerank(&g, &res, 0, igraph_vss_all(), 0, 0.85, 0, &arpack_options);
   print_vector(&res, stdout);
 
+  /* Check personalized PageRank */
+  igraph_personalized_pagerank_vs(&g, &res, 0, igraph_vss_all(), 0, 0.5, igraph_vss_1(1), 0,
+		  &arpack_options);
+  print_vector(&res, stdout);
+
   /* Errors */
   igraph_set_error_handler(igraph_error_handler_ignore);
   ret=igraph_pagerank_old(&g, &res, igraph_vss_all(), 1, -1, 0.0001, 0.85, 0);
@@ -109,13 +114,26 @@ int main() {
   if (ret != IGRAPH_EINVAL) {
     return 3;
   }
-  
+
+  igraph_vector_init(&reset, 2);
+  ret=igraph_personalized_pagerank(&g, &res, 0, igraph_vss_all(), 0, 0.85, &reset, 0, &arpack_options);
+  if (ret != IGRAPH_EINVAL) {
+    return 4;
+  }
+  igraph_vector_resize(&reset, 10);
+  igraph_vector_fill(&reset, 0);
+  ret=igraph_personalized_pagerank(&g, &res, 0, igraph_vss_all(), 0, 0.85, &reset, 0, &arpack_options);
+  if (ret != IGRAPH_EINVAL) {
+    return 5;
+  }
+  igraph_vector_destroy(&reset);
   igraph_destroy(&g);
+  igraph_set_error_handler(igraph_error_handler_abort);
 
   /* Special cases: check for empty graph */
   igraph_empty(&g, 10, 0);
   igraph_pagerank(&g, &res, &value, igraph_vss_all(), 1, 0.85, 0, &arpack_options);
-  if (igraph_finite(value)) {
+  if (value != 1.0) {
     return 6;
   }
   print_vector(&res, stdout);
@@ -127,12 +145,23 @@ int main() {
   igraph_vector_fill(&v, 0);
   igraph_pagerank(&g, &res, &value, igraph_vss_all(), 1, 0.85, &v, &arpack_options);
   igraph_vector_destroy(&v);
-  if (igraph_finite(value)) {
+  if (value != 1.0) {
     return 7;
   }
   print_vector(&res, stdout);
   igraph_destroy(&g);
 
+  /* Another test case for PageRank (bug #792352) */
+  igraph_small(&g, 9, 1, 0, 5, 1, 5, 2, 0, 3, 1, 5, 4, 5, 7, 6, 0, 8, 0, 8, 1, -1);
+  igraph_vector_init(&weights, 9);
+  VECTOR(weights)[0] = 4; VECTOR(weights)[1] = 5; VECTOR(weights)[2] = 5;
+  VECTOR(weights)[3] = 4; VECTOR(weights)[4] = 4; VECTOR(weights)[5] = 4;
+  VECTOR(weights)[6] = 3; VECTOR(weights)[7] = 4; VECTOR(weights)[8] = 4;
+  igraph_pagerank(&g, &res, 0, igraph_vss_all(), 1, 0.85, &weights, &arpack_options);
+  print_vector(&res, stdout);
+  igraph_vector_destroy(&weights);
+  igraph_destroy(&g);
+
   igraph_vector_destroy(&res);
   return 0;
 }
