@@ -1,8 +1,8 @@
 /* -*- mode: C -*-  */
 /* 
    IGraph library.
-   Copyright (C) 2006  Gabor Csardi <csardi@rmki.kfki.hu>
-   MTA RMKI, Konkoly-Thege Miklos st. 29-33, Budapest 1121, Hungary
+   Copyright (C) 2006-2012  Gabor Csardi <csardi.gabor@gmail.com>
+   334 Harvard st, Cambridge MA, 02139 USA
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 */
 
 #include <igraph.h>
+#include <math.h>
 
 int main() {
   
@@ -31,7 +32,7 @@ int main() {
   /* Trivial cases */
 
   igraph_ring(&g, 100, IGRAPH_UNDIRECTED, 0, 0);
-  igraph_reciprocity(&g, &res, 0);
+  igraph_reciprocity(&g, &res, 0, IGRAPH_RECIPROCITY_DEFAULT);
   igraph_destroy(&g);
 
   if (res != 1) {
@@ -43,7 +44,7 @@ int main() {
   igraph_small(&g, 0, IGRAPH_DIRECTED, 
 	       0,  1,  0,  2,  0,  3,  1,  0,  2,  3,  3,  2, -1);
   
-  igraph_reciprocity(&g, &res, 0);
+  igraph_reciprocity(&g, &res, 0, IGRAPH_RECIPROCITY_RATIO);
   igraph_destroy(&g);
 
   if (res != 0.5) {
@@ -51,5 +52,14 @@ int main() {
     return 2;
   }
 
+  igraph_small(&g, 0, IGRAPH_DIRECTED, 0,1,1,2,2,1, -1);
+  igraph_reciprocity(&g, &res, 0, IGRAPH_RECIPROCITY_DEFAULT);
+  igraph_destroy(&g);
+  
+  if (fabs(res - 2.0/3.0) > 1e-15) {
+    fprintf(stderr, "%f != %f\n", res, 2.0/3.0);
+    return 3;
+  }
+
   return 0;
 }
