@@ -1,8 +1,8 @@
 /* -*- mode: C -*-  */
 /* 
    IGraph library.
-   Copyright (C) 2006  Gabor Csardi <csardi@rmki.kfki.hu>
-   MTA RMKI, Konkoly-Thege Miklos st. 29-33, Budapest 1121, Hungary
+   Copyright (C) 2006-2012  Gabor Csardi <csardi.gabor@gmail.com>
+   334 Harvard st, Cambridge MA, 02139 USA
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -24,20 +24,17 @@
 #include <igraph.h>
 #include <stdlib.h>
 
-extern int igraph_rng_inited;
-
 int main() {
 
   igraph_t g1, g2;
   igraph_bool_t iso;
 
-  srand(1122);
-  igraph_rng_inited=1;
+  igraph_rng_seed(igraph_rng_default(), 1122);
   
   igraph_erdos_renyi_game(&g1, IGRAPH_ERDOS_RENYI_GNP, 
 			  100, 3.0/100, /*directed=*/ 0, /*loops=*/ 0);
   
-  srand(1122);
+  igraph_rng_seed(igraph_rng_default(), 1122);
   
   igraph_erdos_renyi_game(&g2, IGRAPH_ERDOS_RENYI_GNP, 
 			  100, 3.0/100, /*directed=*/ 0, /*loops=*/ 0);
